@@ -21,13 +21,7 @@ const NetworksManager = new Lang.Class({
 
         let uri = 'resource:///org/gnome/Polari/data/networks.json';
         let file = Gio.File.new_for_uri(uri);
-        let success, data;
-        try {
-            [success, data, ] = file.load_contents(null);
-            this._parseNetworks(data);
-        } catch(e) {
-            log('Failed to load network list: ' + e.message);
-        }
+        file.load_contents_async(null, Lang.bind(this, this._onContentsReady));
     },
 
     _onContentsReady: function(f, res) {
@@ -38,26 +32,21 @@ const NetworksManager = new Lang.Class({
             log('Failed to load network list: ' + e.message);
             return;
         }
-        if (this._parseNetworks(data))
-            this.emit('changed');
-    },
 
-    _parseNetworks: function(data) {
         let networks;
         try {
             networks = JSON.parse(data);
         } catch(e) {
             log('Failed to parse network list: ' + e.message);
-            return false;
+            return;
         }
 
-        this._networksById.clear();
         this._networks = networks;
         this._networks.forEach(Lang.bind(this,
             function(network) {
                 this._networksById.set(network.id, network);
             }));
-        return true;
+        this.emit('changed');
     },
 
     _lookupNetwork: function(id) {
